local LG = love.graphics
local LK = love.keyboard
require('Core.camera')
local anim8 = require("Core.anim8")

local player = {
    x = 300,
    y = 300,
    hp = 100,
    mp = 100,
    model = LG.newImage("Images/hero.png"),
    animations = {},
    keys = {pressed = {}, Add, Remove}
}

local quads

function player:initMoving()
    local grid = anim8.newGrid(32, 48, 128, 192)

    self.animations.down = anim8.newAnimation("loop", grid("1-4, 1"), 0.1)
    self.animations.down.iddle = anim8.newAnimation("loop", grid("1-1, 1"), 0.1)
    self.animations.left = anim8.newAnimation("loop", grid("1-4, 2"), 0.1)
    self.animations.left.iddle = anim8.newAnimation("loop", grid("1-1, 2"), 0.1)
    self.animations.right = anim8.newAnimation("loop", grid("1-4, 3"), 0.1)
    self.animations.right.iddle = anim8.newAnimation("loop", grid("1-1, 3"), 0.1)
    self.animations.up = anim8.newAnimation("loop", grid("1-4, 4"), 0.1)
    self.animations.up.iddle = anim8.newAnimation("loop", grid("1-1, 4"), 0.1)
    
    self.animations.current = self.animations.down.iddle
    
    self.keys.Add = function(self, key)
        if #self.pressed < 2 then
            table.insert(self.pressed, key)
        end
    end
    
    self.keys.Remove = function(self, key)
        for k, v in pairs(self.pressed) do
            if v == key then
                table.remove(self.pressed, k)
            end
        end
    end
end

function player:updateStats()
	LG.print("Health", camera._x+50, camera._y+100)
	LG.print("Mana", camera._x+50, camera._y+120)
	LG.print(self.hp, camera._x+100, camera._y+100)
	LG.print(self.mp, camera._x+100, camera._y+120)
end

function player:Draw()
	self.animations.current:draw(self.model, self.x, self.y, 0, 1)
end

function player:getX()
    return player.x
end

function player:getY()
    return player.y
end

function player:Move(dt)
	if LK.isDown("up") then
		player.y = player.y - 2.5
	end
	if LK.isDown("left") then
		player.x = player.x - 2.5
	end
	if LK.isDown("down") then
		player.y = player.y + 2.5
	end
	if LK.isDown("right") then
		player.x = player.x + 2.5
	end
    
    self.animations.current:update(dt)
end

function player:setRotate(key, isReleased)
    if isReleased == true then
        if self.animations[key] then
            self.keys:Remove(key)
            if (#self.keys.pressed > 0) then
                self.animations.current = self.animations[self.keys.pressed[1]]
            else
                self.animations.current = self.animations[key].iddle
            end
        end
    else
        if self.animations[key] then 
            self.animations.current = self.animations[key]
            self.keys:Add(key)
        end
    end
end

return player